@@ -1,23 +1,53 @@
 # -*- coding: utf-8 -*-
 
+import sys
+
 import boto3
 import botocore
 import click
-from click.exceptions import Exit
 
+NR_DOCS_ACT_LINKING_URL = "https://docs.newrelic.com/docs/serverless-function-monitoring/aws-lambda-monitoring/enable-lambda-monitoring/account-linking/#manually-configuring-the-license-key-secret"
 NEW_RELIC_ARN_PREFIX_TEMPLATE = "arn:aws:lambda:%s:451483290750"
 RUNTIME_CONFIG = {
-    "dotnetcore3.1": {},
-    "java11": {},
-    "java8.al2": {},
-    "nodejs10.x": {"Handler": "newrelic-lambda-wrapper.handler"},
-    "nodejs12.x": {"Handler": "newrelic-lambda-wrapper.handler"},
-    "provided": {},
-    "provided.al2": {},
-    "python2.7": {"Handler": "newrelic_lambda_wrapper.handler"},
-    "python3.6": {"Handler": "newrelic_lambda_wrapper.handler"},
-    "python3.7": {"Handler": "newrelic_lambda_wrapper.handler"},
-    "python3.8": {"Handler": "newrelic_lambda_wrapper.handler"},
+    "dotnetcore3.1": {"LambdaExtension": True},
+    "java11": {
+        "Handler": "com.newrelic.java.HandlerWrapper::",
+        "LambdaExtension": True,
+    },
+    "java8.al2": {
+        "Handler": "com.newrelic.java.HandlerWrapper::",
+        "LambdaExtension": True,
+    },
+    "nodejs10.x": {
+        "Handler": "newrelic-lambda-wrapper.handler",
+        "LambdaExtension": True,
+    },
+    "nodejs12.x": {
+        "Handler": "newrelic-lambda-wrapper.handler",
+        "LambdaExtension": True,
+    },
+    "nodejs14.x": {
+        "Handler": "newrelic-lambda-wrapper.handler",
+        "LambdaExtension": True,
+    },
+    "provided": {"LambdaExtension": True},
+    "provided.al2": {"LambdaExtension": True},
+    "python2.7": {
+        "Handler": "newrelic_lambda_wrapper.handler",
+        "LambdaExtension": False,
+    },
+    "python3.6": {
+        "Handler": "newrelic_lambda_wrapper.handler",
+        "LambdaExtension": False,
+    },
+    "python3.7": {
+        "Handler": "newrelic_lambda_wrapper.handler",
+        "LambdaExtension": True,
+    },
+    "python3.8": {
+        "Handler": "newrelic_lambda_wrapper.handler",
+        "LambdaExtension": True,
+    },
 }
 
 
@@ -73,8 +103,7 @@ def is_valid_handler(runtime, handler):
 
 
 def error(*args, **kwargs):
-    click.echo(*args, err=True, **kwargs)
-    raise Exit(1)
+    raise click.UsageError(*args, **kwargs)
 
 
 def validate_aws_profile(ctx, param, value):
@@ -82,7 +111,7 @@ def validate_aws_profile(ctx, param, value):
     try:
         boto3.Session(profile_name=value)
     except botocore.exceptions.ProfileNotFound as e:
-        raise click.BadParameter(e.fmt)
+        raise click.BadParameter(e.fmt, ctx=ctx, param=param, param_hint="AWS Profile")
     else:
         return value
 
@@ -115,3 +144,7 @@ def parse_arn(arn):
     else:
         result["resourcetype"], result["resource"] = elements[5].split("/")
     return result
+
+
+def supports_lambda_extension(runtime):
+    return RUNTIME_CONFIG.get(runtime, {}).get("LambdaExtension", False)
